@@ -27,7 +27,7 @@ TASK_DEFAULTS = {
 
 @pytest.fixture
 def run_job_using(mocker, run_transform):
-    m = mocker.patch("taskgraph.util.hash._find_files")
+    m = mocker.patch("taskgraph.util.hash._get_all_files")
     m.return_value = [
         "taskcluster/scripts/toolchain/run.sh",
         "taskcluster/scripts/toolchain/run.ps1",
@@ -184,6 +184,11 @@ def assert_powershell(job, _):
     }
 
 
+def assert_forward(job, _):
+    """Assert unknown schema args are forwarded to run_task"""
+    assert job["run"]["foo"] == "bar"
+
+
 @pytest.mark.parametrize(
     "task",
     (
@@ -222,6 +227,10 @@ def assert_powershell(job, _):
             },
             id="powershell",
         ),
+        pytest.param(
+            {"run": {"foo": "bar"}},
+            id="forward",
+        ),
     ),
 )
 def test_toolchain(request, run_job_using, task):
