@@ -5,7 +5,9 @@
 import datetime
 
 import pytest
-from taskcluster_urls import test_root_url
+
+# prevent pytest thinking this is a test
+from taskcluster_urls import test_root_url as _test_root_url
 
 from taskgraph.util.parameterization import resolve_task_references, resolve_timestamps
 from taskgraph.util.taskcluster import get_root_url
@@ -136,7 +138,7 @@ def test_task_refs_invalid():
 
 @pytest.fixture
 def assert_artifact_refs(monkeypatch):
-    monkeypatch.setenv("TASKCLUSTER_ROOT_URL", test_root_url())
+    monkeypatch.setenv("TASKCLUSTER_ROOT_URL", _test_root_url())
 
     def inner(input, output):
         # Clear memoized function
@@ -159,7 +161,7 @@ def test_artifact_refs_in_list(assert_artifact_refs):
         {
             "in-a-list": [
                 "stuff",
-                test_root_url() + "/api/queue/v1/task/tid1/artifacts/public/foo/bar",
+                _test_root_url() + "/api/queue/v1/task/tid1/artifacts/public/foo/bar",
             ]
         },
     )
@@ -171,7 +173,7 @@ def test_artifact_refs_in_dict(assert_artifact_refs):
         {"in-a-dict": {"stuff": {"artifact-reference": "<edge2/public/bar/foo>"}}},
         {
             "in-a-dict": {
-                "stuff": test_root_url()
+                "stuff": _test_root_url()
                 + "/api/queue/v1/task/tid2/artifacts/public/bar/foo"
             }
         },
@@ -187,9 +189,9 @@ def test_artifact_refs_in_string(assert_artifact_refs):
             }
         },
         {
-            "stuff": test_root_url()
+            "stuff": _test_root_url()
             + "/api/queue/v1/task/tid1/artifacts/public/filename and "
-            + test_root_url()
+            + _test_root_url()
             + "/api/queue/v1/task/tid2/artifacts/public/bar"
         },
     )
@@ -212,7 +214,7 @@ def test_artifact_refs_decision(assert_artifact_refs):
     assert_artifact_refs(
         {"stuff": {"artifact-reference": "<decision/public/artifact>"}},
         {
-            "stuff": test_root_url()
+            "stuff": _test_root_url()
             + "/api/queue/v1/task/tid-decision/artifacts/public/artifact"
         },
     )
