@@ -3,6 +3,7 @@
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 from textwrap import dedent
+from unittest import mock
 
 from taskgraph.util import yaml
 
@@ -10,6 +11,7 @@ from .mockedopen import MockedOpen
 
 
 def test_load():
+    yaml.load_yaml.clear()
     with MockedOpen(
         {
             "/dir1/dir2/foo.yml": dedent(
@@ -20,11 +22,30 @@ def test_load():
             )
         }
     ):
-
         assert yaml.load_yaml("/dir1/dir2", "foo.yml") == {"prop": ["val1"]}
 
 
+@mock.patch("taskgraph.util.yaml.load_stream")
+def test_is_memoized(mocked_load_stream):
+    yaml.load_yaml.clear()
+    with MockedOpen(
+        {
+            "/dir1/dir2/foo.yml": dedent(
+                """\
+                prop:
+                    - val1
+                """
+            )
+        }
+    ):
+        yaml.load_yaml("/dir1/dir2", "foo.yml")
+        yaml.load_yaml("/dir1/dir2", "foo.yml")
+        yaml.load_yaml("/dir1/dir2", "foo.yml")
+        assert mocked_load_stream.call_count == 1
+
+
 def test_key_order():
+    yaml.load_yaml.clear()
     with MockedOpen(
         {
             "/dir1/dir2/foo.yml": dedent(
